Python SANE module 2.9
======================

.. image:: https://github.com/python-pillow/Sane/workflows/Test/badge.svg
    :target: https://github.com/python-pillow/Sane/actions

Python SANE has been split from Python-Pillow as of version 2.7.0.


The SANE module provides an interface to the SANE scanner and frame grabber
interface for Linux.  This module was contributed by Andrew Kuchling formerly
maintained by Ralph Heinkel. It is currently maintained by Sandro Mani.

Build
-----

To build this module, make sure the sane development package is installed. Then, type::

	python setup.py build

In order to install the module type::

	python setup.py install


For some basic documentation please look at the file sanedoc.txt
The example.py script gives a basic example on how to use the software.

Documentation
-------------

Available at https://python-sane.readthedocs.io/en/latest/
